@@ -1,5 +1,5 @@
 package Yancy::Backend::Static;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Build a Yancy site from static Markdown files
 
 #pod =head1 SYNOPSIS
@@ -305,7 +305,7 @@ Yancy::Backend::Static - Build a Yancy site from static Markdown files
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -358,6 +358,12 @@ L<Yancy>, L<Statocles>
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2019 by Doug Bell.
